/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Felamimail **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:51+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Bulgarian (http://www.transifex.com/tine20/tine20/language/bg/)\nLanguage: bg\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Can not combine \"allow external\" and \"allow only members\""
: ""

, "Delete"
: "Изтрий"

, "Reply"
: "Отговори"

, "Reply To All"
: "Отговори на всички"

, "Forward"
: "Препрати"

, "Print Message"
: ""

, "Print Preview"
: ""

, "Add New Account"
: ""

, "Permissions"
: ""

, "Rules"
: ""

, "Vacation, Vacations"
: [
  ""
 ,""

]
, "Account, Accounts"
: [
  "Конто"
 ,"Конто"

]
, "Account Name"
: "Име на конто"

, "Type"
: ""

, "Migration Approved"
: ""

, "Approve Migration"
: ""

, "Do you want to approve the migration of this account?"
: ""

, "User"
: ""

, "User Email"
: "Емайл адрес"

, "User Name (From)"
: "Емайл на подател"

, "Organization"
: "Фирма"

, "Signature position"
: ""

, "Above the quote"
: ""

, "Below the quote"
: ""

, "IMAP"
: "IMAP"

, "Host"
: "Host"

, "Port (Default: 143 / SSL: 993)"
: ""

, "Secure Connection"
: "Сигурна връзка"

, "None"
: "Нищо"

, "TLS"
: "TLS"

, "SSL"
: "SSL"

, "Username"
: "Потребителско име"

, "Password"
: "Парола"

, "Test IMAP Connection"
: ""

, "SMTP"
: "SMTP"

, "Port (Default: 25)"
: ""

, "Authentication"
: "Разпознаване"

, "Login"
: "Login"

, "Plain"
: "Текст"

, "Username (optional)"
: "Ротребителско име (по избор)"

, "Password (optional)"
: "Парола (по избор)"

, "Test SMTP Connection"
: ""

, "Sieve"
: ""

, "Port (Default: 2000)"
: ""

, "Notification Email"
: ""

, "Auto-move notifications"
: ""

, "Auto-move notifications folder"
: ""

, "Other Settings"
: "Други настройки"

, "Sent Folder Name"
: "Име на папка Изпратени"

, "Trash Folder Name"
: "Име на папка Изтрити"

, "Drafts Folder Name"
: ""

, "Templates Folder Name"
: ""

, "Display Format"
: ""

, "HTML"
: ""

, "Plain Text"
: ""

, "Depending on content type (experimental)"
: ""

, "Compose Format"
: ""

, "Preserve Format"
: ""

, "No"
: ""

, "Yes"
: ""

, "Reply-To Email"
: ""

, "It is not possible to convert accounts because the config option EMAIL_USER_ID_IN_XPROPS is disabled."
: ""

, "Migration has not been approved."
: ""

, "It is not possible to convert the account to this type."
: ""

, "System accounts cannot be created manually."
: ""

, "Mailinglist accounts cannot be created manually."
: ""

, "Account type change not possible"
: ""

, "E-Mail account needs a password"
: ""

, "Use"
: ""

, "The grant use the shared email account"
: ""

, "Edit"
: ""

, "The grant edit the shared email account"
: ""

, "Send Mails"
: ""

, "The grant to send mails via the email account"
: ""

, "Warning"
: ""

, "Server connection failed. Do you still want to save this setting and exit?"
: ""

, "Connection succeed"
: ""

, "Connecting to {0} server..."
: ""

, "Connection failed"
: ""

, "{server} Connection Status"
: ""

, "Save Message as"
: ""

, "File (in Filemanager) ..."
: ""

, "Attachment (of Record)"
: ""

, "Download"
: ""

, "{messageCount, plural, one {Message was saved} other {# messages where saved}}"
: ""

, "Success"
: ""

, "Error"
: ""

, "Save Messages as Attachment"
: ""

, "No Messages found."
: ""

, "It is SPAM"
: ""

, "It is not SPAM"
: ""

, "Compose"
: ""

, "Toggle highlighting"
: ""

, "Mark read/unread"
: ""

, "Move"
: ""

, "Copy"
: ""

, "Import Messages"
: ""

, "Add Account"
: "Добави конто"

, "No target folder selected"
: ""

, "You need to select a target folder for the messages."
: ""

, "Wrong File Type"
: ""

, "Files of type eml allowed only."
: ""

, "Importing Messages..."
: ""

, "Id"
: "Id"

, "Attachments"
: "Прикачени документи"

, "Flags"
: ""

, "Subject"
: "Subject"

, "From (Email)"
: ""

, "From (Name)"
: ""

, "Sender"
: ""

, "To"
: "До"

, "Sent"
: "Изпрати"

, "Received"
: "Получени"

, "Folder, Folders"
: [
  ""
 ,""

]
, "Size"
: "Големина"

, "Answered"
: "Отговорени"

, "Forwarded"
: "Препратени"

, "This message might be SPAM"
: ""

, "Tine20"
: ""

, "Encrypted Message"
: ""

, "Filed as:"
: ""

, "Select Message File Location"
: ""

, "Filing Messages"
: ""

, "Error Filing Message"
: ""

, "Could not file message."
: ""

, "Send Reading Confirmation"
: ""

, "Do you want to send a reading confirmation message?"
: ""

, "Empty Folder"
: "Изпразни папка"

, "Add Folder"
: "Добави папка"

, "New {0}"
: "Нова {0}"

, "Please enter the name of the new {0}:"
: "Моля задайте име на новата {0}:"

, "No {0} added"
: "Няма добавена {0}"

, "You have to supply a {0} name!"
: "Трябва да зададете име на {0}!"

, "Please wait"
: "Моя изчакайте"

, "Creating {0}..."
: "Създава {0}..."

, "Edit Account"
: "Редактирай конто"

, "Edit Vacation Message"
: ""

, "Edit Filter Rules"
: ""

, "Notifications"
: ""

, "Mark Folder as read"
: ""

, "Update Folder List"
: ""

, "Message not available."
: ""

, "Cancel"
: ""

, "Ok"
: ""

, "Folders of account {0}"
: ""

, "Folders of all accounts"
: ""

, "Compose email"
: ""

, "CC"
: ""

, "BCC"
: ""

, "Mass Mailing"
: ""

, "Open in Felamimail"
: ""

, "From"
: "От"

, "Add"
: "Добави"

, "Add contact to addressbook"
: "Добави контакт в списъка с адреси"

, "Date"
: ""

, "Show or hide header information"
: "Показва или скрива header"

, "{locationCount, plural, one {This message is filed at the following location} other {This message is filed at the following locations}}: {locationsHtml}"
: ""

, "Open"
: ""

, "Save As"
: ""

, "{attachmentCount, plural, one {Attachment was saved} other {# Attachments where saved}}"
: ""

, "Save as Record Attachment"
: ""

, "This message is probably SPAM. Please help to train your anti-SPAM system with a decision: \"Yes, it is SPAM\" or \"No, it is not\""
: ""

, "Confirm SPAM Suspicion"
: ""

, "Yes, it is SPAM"
: ""

, "No, it is not"
: ""

, "(new message)"
: ""

, "Select recipients for \"{0}\""
: ""

, "Signatures"
: ""

, "Name"
: ""

, "Is Default"
: ""

, "Add Signature"
: ""

, "Edit Signature"
: ""

, "Delete Signature"
: ""

, "Recipient filter"
: ""

, "All recipients"
: ""

, "\"{0}\" recipients"
: ""

, "Attachment"
: ""

, "Filemanager (Download link)"
: ""

, "Filemanager (Download link, password)"
: ""

, "Filemanager (Systemlink)"
: ""

, "Attachment Type"
: ""

, "Click icon to change"
: ""

, "name"
: ""

, "size"
: ""

, "type"
: ""

, "Vacation Message for {0}"
: ""

, "Notification for {0}"
: ""

, "Move up"
: ""

, "Move down"
: ""

, "Enable"
: ""

, "Disable"
: ""

, "ID"
: ""

, "Conditions"
: ""

, "Action"
: ""

, "Keep a copy"
: ""

, "is greater than"
: ""

, "is less than"
: ""

, "Header \"{0}\" contains \"{1}\""
: ""

, "Header \"{0}\" matches \"{1}\""
: ""

, "Sieve Filter Rules"
: ""

, "Sieve Filter Rules for {0}"
: ""

, "From (Email and Name)"
: ""

, "To (Email)"
: ""

, "To (Email CC)"
: ""

, "Header contains"
: ""

, "Header name"
: ""

, "Header value"
: ""

, "Header regex"
: ""

, "Edit Filter Rule"
: ""

, "Apply filter if"
: ""

, "all conditions match"
: ""

, "any condition matches"
: ""

, "Do this action:"
: ""

, "Move mail to folder"
: ""

, "Redirect mail to address"
: ""

, "Reject mail with this text"
: ""

, "Discard mail"
: ""

, "Auto-Reply mail with this text"
: ""

, "Keep mail"
: ""

, "General"
: ""

, "Advanced"
: ""

, "Only send all X days to the same sender"
: ""

, "Incoming mails will be answered with this text:"
: ""

, "Status"
: ""

, "I am available (vacation message disabled)"
: ""

, "I am not available (vacation message enabled)"
: ""

, "Start Date"
: ""

, "Set vacation start date ..."
: ""

, "End Date"
: ""

, "Set vacation end date ..."
: ""

, "Representative #1"
: ""

, "Choose first Representative ..."
: ""

, "Representative #2"
: ""

, "Choose second Representative ..."
: ""

, "Message Template"
: ""

, "Choose Template ..."
: ""

, "Mailvelope decryption Error [{0}]"
: ""

, "To decrypt this message please install {0} with API support enabled"
: ""

, "PGP encrypted Message"
: ""

, "GENDER_Message"
: ""

, "Message, Messages"
: [
  "Съобщение"
 ,"Съобщение"

]
, "Subject/From"
: ""

, "Cc"
: "Копие"

, "Bcc"
: "Сляпо копие"

, "INBOX"
: ""

, "Drafts"
: ""

, "Templates"
: ""

, "Junk"
: ""

, "Trash"
: ""

, "GENDER_Folder"
: ""

, "record list, record lists"
: [
  "Листа на съобщенията"
 ,"Листи на съобщенията"

]
, "Rule, Rules"
: [
  ""
 ,""

]
, "Flag, Flags"
: [
  ""
 ,""

]
, "Flag list, Flag lists"
: [
  ""
 ,""

]
, "Total Messages:"
: ""

, "Unread Messages:"
: ""

, "Name on Server:"
: ""

, "Last update:"
: ""

, "Fetching messages... ({0} done)"
: ""

, "{0} unread message, {0} unread messages"
: [
  ""
 ,""

]
, "New Mail"
: ""

, "Email"
: "Емайл"

, "Active Vacation Message"
: ""

, "Email account \"{0}\" has an active vacation message."
: ""

, "Poll URL: {0}"
: ""

, "{0} as default mailer"
: ""

, "New mails"
: ""

, "You got {0} new mail(s) in folder {1} ({2})."
: ""

, "IMAP Credentials for {0}"
: "IMAP входни данни за {0}"

, "Credentials"
: "Входни данни"

, "IMAP Error"
: ""

, "No connection to IMAP server."
: ""

, "IMAP Credentials Error"
: ""

, "Your email credentials are wrong. Please contact your administrator"
: ""

, "One of your folders was deleted or renamed by another client. Please update the folder list of this account."
: ""

, "SMTP Error"
: ""

, "No connection to SMTP server."
: ""

, "Sieve Error"
: ""

, "No connection to Sieve server."
: ""

, "Save Sieve Script Error"
: ""

, "Could not save script on Sieve server."
: ""

, "Add as \"To\""
: ""

, "Add as \"Cc\""
: ""

, "Add as \"Bcc\""
: ""

, "Remove from recipients"
: ""

, "Loading Mail Addresses"
: ""

, "Click here to set To/CC/BCC."
: ""

, "To:"
: "To:"

, "Cc:"
: "Cc:"

, "Bcc:"
: "Bcc:"

, "Remove"
: ""

, "Send"
: "Изпрати"

, "Search Recipients"
: ""

, "Save As Draft"
: ""

, "Save As Template"
: ""

, "Reading Confirmation"
: ""

, "Activate this toggle button to receive a reading confirmation."
: ""

, "Encrypt Email"
: ""

, "Encrypt email using Mailvelope"
: ""

, "Activate this toggle button to send the mail as separate mail to each recipient."
: ""

, "Click to search for and add recipients from the Addressbook."
: ""

, "Encrypted Content"
: ""

, "Discard this Draft?"
: ""

, "Do you want to discard the current draft?"
: ""

, "Fwd:"
: ""

, "{0} Message"
: ""

, "Failed"
: "Неуспешно"

, "{0} account setting empty."
: ""

, "Files are still uploading."
: ""

, "{locationCount, plural, one {This message will be filed at the following location} other {This message will be filed at the following locations}}: {locationsHtml}"
: ""

, "On {0}, {1} wrote"
: ""

, "Original message"
: "Оригинално съобщение"

, "Compose email:"
: "Напиши емайл:"

, "Convert to formated text"
: ""

, "Body"
: "Съобщение"

, "NOTE: This is mail will be sent as a mass mail, i.e. each recipient will get his or her own copy."
: ""

, "Add email address here for reply-to"
: ""

, "Signature, Signatures"
: [
  ""
 ,""

]
, "Some attachments are of type \"systemlinks\" whereas some of the recipients (marked yellow), couldn't be validated to be accounts on this installation. Only recipients with an active account will be able to open those attachments."
: ""

, "Do you really want to send?"
: ""

, "Empty subject"
: ""

, "Do you really want to send a message with an empty subject?"
: ""

, "No recipients set."
: ""

, "Mass mailing is not allowed for CC or BCC recipients. Please remove them."
: ""

, "Cannot encrypt message. Public keys for the following recipients are missing: {0}"
: ""

, "All inboxes"
: ""

, "Default Email Account"
: "Адрес по настройки"

, "The default email account to use when sending mails."
: "Използван адрес по настройки при изпращане на емайли."

, "Mark Email Automatically As Read"
: ""

, "Is email marked as read automatically or by user action"
: ""

, "Email Update Interval"
: ""

, "How often should Felamimail check for new Emails (in minutes)."
: ""

, "Use for mailto links"
: ""

, "Use Felamimail in mailto links, otherwise use the default desktop client."
: ""

, "Use for NOTES"
: ""

, "Save Note default Value."
: ""

, "Confirm Delete"
: ""

, "Show confirmation dialog when deleting mails."
: ""

, ".eml file Attachment in forwarded mails"
: ""

, "Attach an .eml file to a forwarded mail. Otherwise all attachments separate"
: ""

, "Default Font"
: ""

, "Setting the default font in the E-Mail app"
: ""

, "Mail Type"
: ""

, "Possible mail types."
: ""

, "Additional Personal External Account"
: ""

, "Shared System Account"
: ""

, "Additional Personal System Account"
: ""

, "Default Personal System Account"
: ""

, "Mailinglist"
: ""

, "Mailinglist Reject Reason"
: ""

, "Your email has been rejected"
: ""

, "Vacation Templates Node ID"
: ""

, "Email Notification Templates Node ID"
: ""

, "Custom Vacation Message"
: ""

, "User is allowed to set custom vacation message for system account"
: ""

, "Cache email body"
: ""

, "Should the email body be cached (recommended for slow IMAP server connections)"
: ""

, "Delete Archived Mail"
: ""

, "Prevent copying mails in the same account"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Felamimail Application."
: ""

, "Account Migration"
: ""

, "Shows context menu for system accounts to approve migration"
: ""

, "Move notifications"
: ""

, "Move notifications to a subfolder via sieve"
: ""

, "Auto-Save Drafts"
: ""

, "Save drafts automatically while editing an email"
: ""

, "Only password download link"
: ""

, "Allow only password download link"
: ""

, "Tine 2.0 Flag"
: ""

, "Add a Tine 2.0 flag to sent messages"
: ""

, "Show Reply-To"
: ""

, "Show Reply-To field in message compose dialog"
: ""

, "Auto-Create Folders"
: ""

, "Create template, trash, sent, draft and junks folders for system accounts"
: ""

, "Enable Spam Suspicion Strategy"
: ""

, "SEnable pam Suspicion Strategy"
: ""

, "Spam Suspicion Strategy"
: ""

, "Spam Suspicion Strategy Config"
: ""

, "Spam User Processing Pipeline"
: ""

, "Confirm SPAM Suspicion Message"
: ""

, "Message for users when they press the info button in a SPAM suspicion toolbar."
: ""

, "Filter E-Mail URIs"
: ""

, "Should the email body uris be filtered. Only anchors with URIs are allowed if this is turned on"
: ""

, "System Account Folder Defaults"
: ""

, "Paths of the special folders (like Sent, Trash, ...)"
: ""

, "Allow self signed TLS cert for IMAP connection"
: ""

, "Sieve Redirect Only Internal"
: ""

, "Allow only sieve redirect rules to internal (primary/secondary) email addresses"
: ""

, "Sieve Notification Bounces Reporting Email"
: ""

, "URL icon path for own domain"
: ""

, "Used to mark messages from configured primary and secondary domains"
: ""

, "URL icon path for other domains"
: ""

, "Used to mark messages from all other domains"
: ""

, "Other domain regex for FLAG_ICON_OTHER_DOMAIN"
: ""

, "shared / adb_list accounts need to have a password set"
: ""

, "Is default"
: ""

, "Email Account, Email Accounts"
: [
  ""
 ,""

]
, "IMAP Host"
: ""

, "IMAP Port"
: ""

, "IMAP SSL"
: ""

, "Sent Folder"
: ""

, "Trash Folder"
: ""

, "Drafts Folder"
: ""

, "Templates Folder"
: ""

, "Reply-To"
: ""

, "E-Mail"
: ""

, "Signature Position"
: ""

, "SMTP Host"
: ""

, "SMTP Port"
: ""

, "SMTP SSL"
: ""

, "SMTP Authentication"
: ""

, "Sieve Host"
: ""

, "Sieve Port"
: ""

, "Sieve SSL"
: ""

, "Reading Confirmation:"
: ""

, "Your message:"
: ""

, "Received on"
: ""

, "Was read by:"
: ""

, "on"
: ""

, "Message File Location, Message File Locations"
: [
  ""
 ,""

]
, "Message File Locations"
: ""

, "Message ID Hash"
: ""

, "Message ID"
: ""

, "Model"
: ""

, "Record ID"
: ""

, "Record Title"
: ""

, "Node ID"
: ""

, "Message File Suggestion, Message File Suggestions"
: [
  ""
 ,""

]
, "Message File Suggestions"
: ""

, "Out of Office reply from %1$s"
: ""

, "It is not allowed to redirect emails to self! Please change the recipient."
: ""

, "Redirects to external email domains are not allowed."
: ""

, "You have new mail from "
: ""

, "shared / adb_list accounts need to have an email set"
: ""

, "userInternal accounts are only allowed with Tinebase_Config::EMAIL_USER_ID_IN_XPROPS"
: ""

, "userInternal accounts need to have an email set"
: ""

, "userInternal accounts need to have an user_id set"
: ""

, "Please choose a new email address for userInternal accounts"
: ""

, "system account for user does not exist"
: ""

, "Account type cannot be changed from {0} to {1}"
: ""

, "Config EMAIL_USER_ID_IN_XPROPS is not enabled! Please check if your email user backend supports it and run CLI method Tinebase.emailUserIdInXprops"
: ""

, "Migration of this account has not been approved!"
: ""

, "Could not find email user xprops!"
: ""

, "Internal user accounts need a valid user"
: ""

, "System account of user is missing"
: ""

, "Bad recipient address syntax"
: ""

, "Recipient address rejected"
: ""

, "Original message not found, email was moved or deleted"
: ""

, "Invalid address format"
: ""

, "Error: %s"
: ""

, "Could not send message"
: ""

, "My Mail Download Links"
: ""

, "Seen"
: ""

, "Deleted"
: ""

, "Draft"
: ""

, "Flagged"
: ""

, "It is not allowed to copy e-mails in the same account."
: ""

, "Folder with name {0} already exists!"
: ""

, "Failure on create folder"
: ""

, "All inboxes of my email accounts"
: ""

, "All unread mail"
: ""

, "All unread mail of my email accounts"
: ""

, "All highlighted mail"
: ""

, "All highlighted mail of my email accounts"
: ""

, "All drafts"
: ""

, "All mails with the draft flag"
: ""

, "IMAP Hostname missing"
: ""

, "IMAP Credentials missing"
: ""

, "SMTP Hostname missing"
: ""

, "SMTP Credentials missing"
: ""

, "manage email accounts"
: ""

, "Edit and delete email accounts"
: ""

, "Add email accounts"
: ""

, "Create new email accounts"
: ""

, "Vacation"
: ""

, "Account"
: "Конто"

, "Folder"
: ""

, "Message"
: "Съобщение"

, "record list"
: "Листа на съобщенията"

, "Rule"
: ""

, "Flag"
: ""

, "Flag list"
: ""

, "{0} unread message"
: ""

, "Signature"
: ""

, "Email Account"
: ""

, "Message File Location"
: ""

, "Message File Suggestion"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true; 
